@@ -238,6 +238,7 @@ class RestoreJob(object):
                 is_seed = True if self.fqdn_resolver.resolve_fqdn(restore_host) in self._get_seeds_fqdn() else False
                 self.host_map[restore_host] = {'source': [hosts[0]], 'seed': is_seed}
                 i += 1
+            logging.debug("self.host_map: {}".format(self.host_map))
         else:
             # Topologies are different between backup and restore clusters. Using the sstableloader for restore.
             self.use_sstableloader = True
@@ -261,15 +262,41 @@ class RestoreJob(object):
         seeds = list()
         for seed in self.cassandra.seeds:
             seeds.append(self.fqdn_resolver.resolve_fqdn(seed))
+        logging.debug("seeds are: {}".format(seeds))
         return seeds
 
     def _populate_hostmap(self):
+        """
+        When there are no seed nodes to pull cluster topology from, the essential information required for a restore
+            can be passed in via a simple file using the --host-list CLI argument.
+
+        Each line in the file must have three pieces of information in this order:
+            - the string `True` or `False`; This indicates if the source node was a seed node
+            - the host/ip that the restore operation is to take place on / destination node
+            - the host/ip where the data came from / source node
+        Each field is separated by a comma.
+
+        E.G.: Using medusa to restore a 4 node cluster from a previous backup taken of that same cluster:
+            medusa@cassandra-node01:~$ cat nodes.list
+            True,10.10.1.127,10.10.1.127
+            True,10.10.1.128,10.10.1.128
+            False,10.10.1.129,10.10.1.129
+            False,10.10.1.130,10.10.1.130
+
+        :return:
+        """
         with open(self.host_list, 'r') as f:
             for line in f.readlines():
-                seed, target, source = line.replace('\n', '').split(self.config.storage.host_file_separator)
+                # Remove leading/trailing whitespace
+                _line = line.strip()
+                # Ignore comment lines
+                if _line.startswith('#'):
+                    continue
+                seed, target, source = _line.split(self.config.storage.host_file_separator)
                 # in python, bool('False') evaluates to True. Need to test the membership as below
-                self.host_map[self.fqdn_resolver.resolve_fqdn(target.strip())] \
-                    = {'source': [self.fqdn_resolver.resolve_fqdn(source.strip())], 'seed': seed in ['True']}
+                target_resolved = self.fqdn_resolver.resolve_fqdn(target.strip())
+                source_resolved = self.fqdn_resolver.resolve_fqdn(source.strip())
+                self.host_map[target_resolved] = {'source': [source_resolved], 'seed': seed in ['True']}
 
     def _restore_data(self):
         # create workdir on each target host
@@ -282,7 +309,7 @@ class RestoreJob(object):
         for target, sources in self.host_map.items():
             logging.info('About to restore on {} using {} as backup source'.format(target, sources))
 
-        logging.info('This will delete all data on the target nodes and replace it with backup {}.'
+        logging.info("This will delete all data on the target nodes and replace it with backup '{}'."
                      .format(self.cluster_backup.name))
 
         proceed = None
